@@ -22,13 +22,25 @@ def test_mht_web_run():
     for row in rows:
         md = SchoolMhtWebData(**row)
         assert len(md.scale_student_score) == 3
-        assert len(md.sub_scale_score) == 4
+        assert len(md.sub_scale_score) == 3
         assert len(md.grade_scale_student_score) == 3
         assert len(md.grade_special_students) == 3
 
         data = [
             md.scale_student_score, md.sub_scale_score,
-            md.grade_scale_student_score, md.grade_special_students
+            md.grade_scale_student_score, md.grade_sub_scale_score,
+            md.grade_special_students
         ]
         for d in data:
             validate_data_for_web(d)
+
+        assert len(md.scale_student_score['x_axis']) == 101
+        assert len(md.scale_student_score['y_axis']) == 101
+        special_students_count = [5, 4, 9]
+        for i, (k, v) in enumerate(md.grade_special_students.items()):
+            assert len(v) == special_students_count[i]
+    # OK 207 -> 187 效度>7 筛选20
+
+    # NO 总量表分（包含效度） > 65， 正确 包含效度 18人, HawaData 20人， 原因为 去掉效度题（重复计算 score ）后，只有90题，导致总分增大。
+
+    # 刘紫凝 66 宋子晨 68
